@@ -9,12 +9,12 @@ estimateGraphPickFreeze <- function(f.mat, d, q, q.arg, n.pf, print.loop.index,
   Z <- matrix(nrow = n.pf, ncol = d)
   for (j in 1:d) Z[, j] <- do.call(q[j], c(list(p = Z.01[, j]), 
                                            q.arg[[j]]))
-  y.all <- f.mat(X) # ... missing!
+  y.all <- f.mat(X, ...) 
   y.but.i <- matrix(,n.pf,d)
   for (i in 1:d){
     X2 <- X
     X2[,i] <- Z[,i]
-    y.but.i[,i] <- f.mat(X2) # ... missing!
+    y.but.i[,i] <- f.mat(X2, ...)  
   }
   D <- var(c(y.all, y.but.i))*(n.pf-1)/n.pf
   DC.but.i <- numeric(d)
@@ -38,18 +38,3 @@ estimateGraphPickFreeze <- function(f.mat, d, q, q.arg, n.pf, print.loop.index,
   rownames(totalInt) <- inter
   return(totalInt)
 }
-
-# test
-# f.mat <- ishigami.fun
-# d <- 3
-# q <- rep("qunif",d)
-# q.arg <- rep(list(list(min=-pi, max=pi)),d)
-# n.pf = 10000
-# 
-# n.sim <- 500
-# x <- matrix(,nrow=n.sim, ncol=3)
-# for (i in 1:n.sim){
-#   x[i,] <- estimateGraphPickFreezeSaltelliNdplus1(f.mat=f.mat, d=d, q=q, q.arg=q.arg, n.pf=n.pf)
-# }
-# apply(x, 2, var) #  0.01372603 0.03981987 0.02505435
-# # 0.01279237 0.02826905 0.01406206 | 
