@@ -1,4 +1,4 @@
 library(testthat)
 library(fanovaGraph)
 
-test_package("fanovaGraph")
\ No newline at end of file
+test_check("fanovaGraph")
\ No newline at end of file
